#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-test-utils
version:              2.3.0.0
visibility:           public
id:                   hls-test-utils-2.3.0.0-IkcgKbRlRdX4AMtcTrLbE1
key:                  hls-test-utils-2.3.0.0-IkcgKbRlRdX4AMtcTrLbE1
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Utilities used in the tests of Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  fa226f84d9cfc1b832a8d90f14551399
exposed:              True
exposed-modules:      Test.Hls Test.Hls.FileSystem Test.Hls.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-test-utils
hs-libraries:         HShls-test-utils-2.3.0.0-IkcgKbRlRdX4AMtcTrLbE1
depends:
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT
    async-2.2.6-13RsU0DgnQr2Fu0srq1209 base-4.18.2.1
    blaze-markup-0.8.3.0-DDuKg87sJ0pLWg6HCDFYiH bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 extra-1.7.16-5TJRL61mQdJ37nJ79jr8U
    filepath-1.4.300.1 ghcide-2.3.0.0-78iRkwjTMmGGIR2bvJufIi
    hls-graph-2.3.0.0-4X3yADOKJezCfW676tAtn2
    hls-plugin-api-2.3.0.0-PV4VuNiiei50o1roJRQC9
    lens-5.3.4-CugvPwDQfTKJtJ2DRsVKfV
    lsp-2.2.0.0-ASJx8lMy3AeIMffE9ZbIv9
    lsp-test-0.16.0.0-JtHaOzTMjeB1QjnjsP9KZC
    lsp-types-2.0.2.0-9I6W00SGQct8ofSsEutf7C
    row-types-1.0.1.2-5hwpxSgR0dCfLegwSqtEH
    tasty-1.5.3-6dATjK2GfiuKOdbpItHINb
    tasty-expected-failure-0.12.3-7qZRFUUh7cRBr9PDLft3Ea
    tasty-golden-2.3.6-6coc7sAymCAL4msY6BBGWD
    tasty-hunit-0.10.2-KGbRGotZbhFnUjCpSchXP
    tasty-rerun-1.1.20-JsO8ctROSD6KsNjYV9HBiI
    temporary-1.3-HgSGYx8rMrE1HkWShJwAxb text-2.0.2
    unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits

haddock-interfaces:
    /usr/share/doc/haskell-hls-test-utils/html/hls-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-hls-test-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

